@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.2.") or
-    raise "ruby lib version (3.2.9) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.2.10) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.2/3.2.0/x86_64-darwin16")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "2"
-  CONFIG["TEENY"] = "9"
-  CONFIG["PATCHLEVEL"] = "265"
+  CONFIG["TEENY"] = "10"
+  CONFIG["PATCHLEVEL"] = "266"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
@@ -41,11 +41,11 @@ module RbConfig
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.2.9"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.2.10"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=3.2' '--with-rubyhdrdir=/opt/local/include/ruby-3.2.9' '--with-rubylibprefix=/opt/local/lib/ruby3.2' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/opt/local/bin/clang-mp-16' 'CXX=/opt/local/bin/clang++-mp-16' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--without-gmp' '--without-jemalloc' '--with-opt-dir=/opt/local' '--program-suffix=3.2' '--with-rubyhdrdir=/opt/local/include/ruby-3.2.10' '--with-rubylibprefix=/opt/local/lib/ruby3.2' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' '--with-arch=x86_64' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' 'CC=/opt/local/bin/clang-mp-16' 'CXX=/opt/local/bin/clang++-mp-16' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
